@@ -14,13 +14,14 @@
 
 """Interface for the Matter Level Control cluster capability."""
 import abc
+from gazoo_device.capabilities import matter_enums
 from gazoo_device.capabilities.matter_clusters.interfaces import cluster_base
 
 
 class LevelControlClusterBase(cluster_base.ClusterBase, metaclass=abc.ABCMeta):
   """Matter Level Control cluster capability."""
 
-  CLUSTER_ID = 0x0008
+  CLUSTER_ID = matter_enums.LevelControlCluster.ID
 
   @abc.abstractmethod
   def move_to_level(self, level: int, verify: bool = True) -> None:
