@@ -45,11 +45,13 @@ logger = gdm_logger.get_logger()
 
 JLINK_COMMS_PRODUCT_NAME = "J-Link"
 CP2104_COMMS_PRODUCT_NAME = "CP2104"
+USB_COMMS_PRODUCT_NAME = "USB Single Serial"
 NRF_DK_COMMS_ADDRESS_LINUX = "SEGGER_J-Link"
 NRF_DK_EFR32_COMMS_ADDRESS_MAC = "tty.usbmodem"
 EFR32_COMMS_ADDRESS_LINUX = "Silicon_Labs_J-Link"
-ESP32_M5STACK_COMMS_ADDRESS_LINUX = "Silicon_Labs_CP2104"
-ESP32_M5STACK_COMMS_ADDRESS_MAC = "tty.usbserial"
+ESP32_M5STACK_CP2104_COMMS_ADDRESS_LINUX = "Silicon_Labs_CP2104"
+ESP32_M5STACK_CP2104_COMMS_ADDRESS_MAC = "tty.usbserial"
+ESP32_M5STACK_CH9102F_COMMS_ADDRESS_LINUX = "1a86_USB_Single_Serial"
 
 
 def _validate_comm_types(
@@ -382,11 +384,14 @@ class PigweedSerialComms(CommunicationType):
 
   @classmethod
   def get_comms_addresses(cls) -> List[str]:
-    include_product = [JLINK_COMMS_PRODUCT_NAME, CP2104_COMMS_PRODUCT_NAME]
+    include_product = [
+        JLINK_COMMS_PRODUCT_NAME, CP2104_COMMS_PRODUCT_NAME,
+        USB_COMMS_PRODUCT_NAME]
     include_address = [
         NRF_DK_COMMS_ADDRESS_LINUX, NRF_DK_EFR32_COMMS_ADDRESS_MAC,
-        EFR32_COMMS_ADDRESS_LINUX, ESP32_M5STACK_COMMS_ADDRESS_LINUX,
-        ESP32_M5STACK_COMMS_ADDRESS_MAC
+        EFR32_COMMS_ADDRESS_LINUX, ESP32_M5STACK_CP2104_COMMS_ADDRESS_LINUX,
+        ESP32_M5STACK_CP2104_COMMS_ADDRESS_MAC,
+        ESP32_M5STACK_CH9102F_COMMS_ADDRESS_LINUX
     ]
     match_criteria = {
         "product_name": {
